function [u,time] = RotatingHill2Dex5(u, FinalTime, cx, cy, ufun)
% function [u,time] = RotatingHill2Dex5(u, FinalTime, cx, cy, alpha)
% Purpose : Integrate 2D advection equation until FinalTime starting with
%           initial condition u
%
% By Allan P. Engsig-Karup, apek@imm.dtu.dk.

Globals2D;
time = 0;

% Runge-Kutta residual storage  
resu = zeros(Np,K); 

% compute time step size
rLGL = JacobiGQ(0,0,N); rmin = abs(rLGL(1)-rLGL(2));
dtscale = dtscale2D; dt = min(dtscale)*rmin*2/3/max(abs([cx(:);cy(:)]));

% outer time step loop 
tstep = 0;
while (time<FinalTime)
  tstep= tstep+1;
  if(time+dt>FinalTime), dt = FinalTime-time; end

   for INTRK = 1:5    
       timelocal = time + rk4c(INTRK)*dt;
       [rhsu] = RotatingHillRHS2Dupwindex5(u, timelocal, cx, cy, ufun);
       resu   = rk4a(INTRK)*resu + dt*rhsu;  
       u = u+rk4b(INTRK)*resu;
   end
   % Increment time
   time = time+dt;
   if mod(tstep,20)==0
     ua = ufun(x,y,time);
     err = u-ua;
     subplot(1,3,1)
     PlotField2D(N, x, y, err); 
     subplot(1,3,2)
     PlotField2D(N, x, y, u); 
     axis([-1 1 -1 1 -1 1])
     xlabel('x'), ylabel('y'), zlabel('u(x,y,t)')
     title(sprintf('time = %.2f',time))
     subplot(1,3,3)
     PlotField2D(N, x, y, ua); 
     axis([-1 1 -1 1 -1 1])
     set(gcf,'position',[391 753 1315 341])
     drawnow
   end
end
return
