close all, clear all, clc
warning off
% Driver script for solving the 2D advection equation with varying
% coefficients. Rotating Hill problem.
%
% By Allan P. Engsig-Karup, apek@imm.dtu.dk.
Globals2D;

% Polynomial order used for approximation
N = 6;
FinalTime = 1;

% Create Mesh
NN = 6;
X = linspace(-1,1,NN);
[VX,VY]= meshgrid(X,X); VX = VX(:)'; VY = VY(:)';
EToV = delaunay(VX,VY);
K = size(EToV,1); Nv = length(VX(:));

% Initialize solver and construct grid and metric
StartUp2D;

% Set initial conditions
t = 0;
lambda0 = 1/8; x0 = -0.5; y0 = 0;
r0 = sqrt(x0^2+y0^2);
cx = 2*pi*y; cy = -2*pi*x;
ufun = @(x,y,t) exp(-(x+r0*cos(2*pi*t)).^2/(2*lambda0^2)).*...
    exp(-(y-r0*sin(2*pi*t)).^2/(2*lambda0^2));

u = ufun(x,y,t);

% Solve Problem
disp('  Solving...')
[u,time] = RotatingHill2Dex5(u, FinalTime, cx, cy, ufun);

subplot(1,3,2)
PlotField2D(N, x, y, u);
axis([-1 1 -1 1 -1 1])
xlabel('x'), ylabel('y'), zlabel('u(x,y,t)')
title(sprintf('time = %.2f',time))
drawnow
