function [rhsu] = RotatingHillRHS2Dupwindex5(u, timelocal, cx, cy, ufun)
% function [rhsu] = RotatingHillRHS2Dupwindex5(u, timelocal, a, alpha)
% Purpose  : Evaluate RHS flux in 2D advection equation with
%            varying coefficients using upwinding fluxes.
%
% By Allan P. Engsig-Karup, apek@imm.dtu.dk.
Globals2D;

% Define flux differences at faces
df = zeros(Nfp*Nfaces,K); 

% phase speed in normal directions
cn = cx(vmapM).*nx(:) + cy(vmapM).*ny(:); 

% if cn>=1 then outflow => pick uM
% if cn<1 then inflow   => pick uP
ustar = 0.5*(cn+abs(cn)).*u(vmapM) + 0.5*(cn-abs(cn)).*u(vmapP);

% Impose boundary conditions at inflow
uin = ufun(Fx,Fy,timelocal);
uM  = u(vmapM);

ustar(mapB) = 0.5*(cn(mapB)+abs(cn(mapB))).*uM(mapB) +...
              0.5*(cn(mapB)-abs(cn(mapB))).*uin(mapB);

df(:) = cn.*uM - ustar;

% Impose boundary conditions at inflow
uin = ufun(x,y,timelocal);

% local derivatives of fields
[ux,uy] = Grad2D(u); 

% compute right hand sides of the PDE's
rhsu  = -(cx.*ux + cy.*uy) + LIFT*(Fscale.*df);
return


